@@ -1,3 +1,5 @@
+from regulargrid.regulargrid import RegularGrid
+import numpy
 
 def test_regular_grid():
 	rg = RegularGrid([(0,1), (0,1)], numpy.array([[], []]), numpy.array([[1, 2], [3, 4]]))
@@ -8,7 +10,7 @@ def test_regular_grid():
 if __name__ == '__main__':
 	numpy.random.seed(0)
 	limits = [(-10,10), (-3,3)]
-	breaks = [numpy.array(sorted(numpy.random.uniform(lo,hi, size=50))) for lo,hi in limits]
+	breaks = [numpy.array(sorted(numpy.random.uniform(lo, hi, size=50))) for lo,hi in limits]
 	
 	npoints = numpy.product([len(b)+2 for b in breaks])
 	inputvalues = []
